@@ -1083,7 +1083,7 @@ totemPlugin::ParseBoolean (const char *key,
         char *endptr = NULL;
         errno = 0;
         long num = g_ascii_strtoll (value, &endptr, 0);
-        if (!endptr && errno == 0) {
+        if (endptr != value && errno == 0) {
                 return num > 0;
         }
         
@@ -1506,14 +1506,6 @@ totemPlugin::Init (NPMIMEType mimetype,
 {
 	D ("Init mimetype '%s' mode %d", (const char *) mimetype, mode);
 
-	/* Make sure the plugin stays resident, to avoid
-	 * reloading the GObject types.
-	 */
-	CallNPN_SetValueProc (sNPN.setvalue,
-			      mInstance,
-			      NPPVpluginKeepLibraryInMemory,
-			      NS_INT32_TO_PTR (PR_TRUE));
-
 	/* mode is NP_EMBED, NP_FULL, or NP_BACKGROUND (see npapi.h) */
 	/* FIXME we should error out if we are in fullscreen mode
 	 * FIXME: This might be possible on gecko trunk by returning an
